@@ -82,9 +82,9 @@ GPOFontMap::~GPOFontMap()
   }
 }
 
-void GPOFontMap::startDoc(XRef *xref)
+void GPOFontMap::startDoc(XRef *xrefA)
 {
-  this->xref = xref;
+  this->xref = xrefA;
   
   if (embeddedFonts != NULL)
     g_hash_table_destroy(embeddedFonts);
