@@ -135,7 +135,7 @@ struct _GPdfAnnotsViewPrivate {
 	GnomeUIInfo *popup_menu_uiinfo;
 	GtkWidget *popup_menu;
 
-	Annots *annots;
+	guint total_annots;
 	UnicodeMap *umap;
 
 	gint current_page;
@@ -144,7 +144,6 @@ struct _GPdfAnnotsViewPrivate {
 };
 
 static void	gpdf_annots_view_class_init	   	     (GPdfAnnotsViewClass*); 
-static void	gpdf_annots_view_class_finalize    	     (gpointer, gpointer); 
 static void	gpdf_annots_view_dispose	   	     (GObject*); 
 static void	gpdf_annots_view_finalize	   	     (GObject*); 
 static void	gpdf_annots_view_instance_init     	     (GPdfAnnotsView*);
@@ -171,6 +170,7 @@ enum {
 enum {
 	ANNOT_SELECTED_SIGNAL = 0,
 	ANNOT_TOGGLED_SIGNAL,
+	READY_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -264,6 +264,16 @@ gpdf_annots_view_class_init (GPdfAnnotsViewClass *klass)
             G_TYPE_POINTER,
             G_TYPE_INT,
 	    G_TYPE_BOOLEAN);
+
+	gpdf_annots_view_signals [READY_SIGNAL] =
+	  g_signal_new (
+	    "ready",
+	    G_TYPE_FROM_CLASS (gobject_class),
+	    G_SIGNAL_RUN_LAST,
+	    G_STRUCT_OFFSET (GPdfAnnotsViewClass, ready),
+	    NULL, NULL,
+	    gpdf_marshal_VOID__VOID,
+	    G_TYPE_NONE, 0);
 }
 
 static void
@@ -288,11 +298,10 @@ gpdf_annots_view_emit_annot_toggled (GPdfAnnotsView *annots_view,
 }
 
 static void
-gpdf_annots_view_init (GPdfAnnotsView *annots_view)
+gpdf_annots_view_emit_ready (GPdfAnnotsView *annots_view)
 {
-  GtkScrolledWindow *window;
-
-  window = GTK_SCROLLED_WINDOW (annots_view);
+	g_signal_emit (G_OBJECT (annots_view),
+		       gpdf_annots_view_signals [READY_SIGNAL], 0);
 }
 
 #define GPDF_RENDER_STOCK_ICON(widget, dest, id, size) 					\
@@ -323,7 +332,7 @@ gpdf_annots_view_construct (GPdfAnnotsView *annots_view)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (annots_view),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (annots_view),
-					     GTK_SHADOW_IN);
+					     GTK_SHADOW_NONE);
 
 	priv->listview = gtk_tree_view_new ();
 	gtk_widget_show (priv->listview);
@@ -517,7 +526,6 @@ gpdf_annots_view_annot_select_func (GtkTreeSelection *selection,
         GPdfAnnotData *annot_data; 
 	GValue selection_item = {0,};
 	GtkTreeIter iterator;
-	gchar *title;
 	gboolean ret = FALSE;
 
 	annots_view = GPDF_ANNOTS_VIEW (data);
@@ -642,6 +650,20 @@ gpdf_annots_view_is_annot_displayed (Annot *annot, gpointer user_data)
 	return (((found && active) || !found) ? gTrue : gFalse);
 }
 
+static gboolean
+gpdf_annots_view_have_annotations (GPdfAnnotsView *annots_view)
+{
+	GPdfAnnotsViewPrivate *priv;
+	
+	g_return_val_if_fail
+	  (GPDF_IS_NON_NULL_ANNOTS_VIEW (annots_view),
+	   FALSE);
+	
+	priv = annots_view->priv;
+	
+	return (priv->total_annots > 0);
+}
+
 static void
 gpdf_annots_view_update_annots_list (GPdfAnnotsView *annots_view,
                                      GtkTreeIter    *iter, 
@@ -667,7 +689,8 @@ gpdf_annots_view_update_annots_list (GPdfAnnotsView *annots_view,
         //g_message ("Page #%d have %d annots", page_nr, num_annots);
 
         if (!num_annots) return;
-              
+	      
+	priv->total_annots += num_annots;
         for (annot_nr = 0, annot = annots->getAnnot (0);
              annot_nr < num_annots;
              annot = annots->getAnnot (++annot_nr)) {
@@ -763,10 +786,6 @@ gpdf_annots_view_populate_idle (GPdfAnnotsView *annots_view)
         GtkTreeIter iter; 
         gint num_pages;
         gint page;
-        Page *the_page;
-        Object annots_obj;
-        Annots *annots;
-        XRef *xref;
 
 	g_return_val_if_fail (GPDF_IS_NON_NULL_ANNOTS_VIEW (annots_view),
 			      TRUE);
@@ -801,6 +820,10 @@ gpdf_annots_view_populate_idle (GPdfAnnotsView *annots_view)
         /* Navigate through all pages to get annotations */
 	num_pages = priv->pdf_doc->getNumPages ();
         for (page = 1; page < num_pages; page++) {
+		Page *the_page;
+		Object annots_obj;
+		Annots *annots;
+		XRef *xref;
 
 		the_page = priv->pdf_doc->getCatalog ()->getPage (page);
                 xref = priv->pdf_doc->getXRef();
@@ -813,51 +836,60 @@ gpdf_annots_view_populate_idle (GPdfAnnotsView *annots_view)
                                                      annots,
                                                      page,
                                                      priv->current_page);
+		delete annots;
         }
 	gtk_tree_view_set_model (GTK_TREE_VIEW (priv->listview),
 				 GTK_TREE_MODEL (priv->model));
-	
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->listview));
-	gtk_tree_selection_set_select_function (selection,
-			gpdf_annots_view_annot_select_func,
-			annots_view, NULL);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->listview), TRUE);
+	if (gpdf_annots_view_have_annotations (annots_view)) {
+	
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->listview));
+		gtk_tree_selection_set_select_function (selection,
+							gpdf_annots_view_annot_select_func,
+							annots_view, NULL);
+		
+		gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->listview), TRUE);
+		
+		renderer = gtk_cell_renderer_pixbuf_new ();
+		column = gtk_tree_view_column_new_with_attributes (NULL, renderer,
+								   "pixbuf", GPDF_ANNVIEW_COLUMN1, 
+								   NULL);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (priv->listview), column);
+		
+		renderer = gtk_cell_renderer_text_new ();
+		column = gtk_tree_view_column_new_with_attributes (_("Owner/Title"), renderer,
+								   "text", GPDF_ANNVIEW_COLUMN2,
+								   NULL);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (priv->listview), column);
+		
+		renderer = gtk_cell_renderer_toggle_new ();
+		g_signal_connect (renderer, "toggled",
+				  G_CALLBACK (gpdf_annots_view_toggled_callback),
+				  (gpointer)annots_view);
+		column = gtk_tree_view_column_new_with_attributes (_("Opened"), renderer,
+								   "active", GPDF_ANNVIEW_COLUMN3,
+								   NULL);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (priv->listview), column);
+		
+		/* Activate popup menu items */
+		if (GTK_IS_WIDGET (priv->popup_menu_uiinfo[POPUP_MENU_SHOW_ALL_INDEX].widget))
+		  gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_SHOW_ALL_INDEX].widget,
+					    TRUE); 
+		
+		if (GTK_IS_WIDGET (priv->popup_menu_uiinfo[POPUP_MENU_HIDE_ALL_INDEX].widget))
+		  gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_HIDE_ALL_INDEX].widget, 
+					    TRUE); 
+		
+		if (GTK_IS_WIDGET (priv->popup_menu_uiinfo[POPUP_MENU_FILTER_INDEX].widget))
+		  gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_FILTER_INDEX].widget, 
+					    FALSE); 
+		
+		if (GTK_IS_WIDGET (priv->popup_menu_uiinfo[POPUP_MENU_PLUGINS_INDEX].widget))
+		  gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_PLUGINS_INDEX].widget, 
+					    FALSE); 
+	}
 
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	column = gtk_tree_view_column_new_with_attributes (NULL, renderer,
-							   "pixbuf", GPDF_ANNVIEW_COLUMN1, 
-							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (priv->listview), column);
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Owner/Title"), renderer,
-							   "text", GPDF_ANNVIEW_COLUMN2,
-							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (priv->listview), column);
-	
-	renderer = gtk_cell_renderer_toggle_new ();
-	g_signal_connect (renderer, "toggled",
-			  G_CALLBACK (gpdf_annots_view_toggled_callback),
-			  (gpointer)annots_view);
-	column = gtk_tree_view_column_new_with_attributes (_("Opened"), renderer,
-							   "active", GPDF_ANNVIEW_COLUMN3,
-							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (priv->listview), column);
-
-	/* Activate popup menu items */
-	gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_SHOW_ALL_INDEX].widget,
-				  TRUE); 
-	
-	gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_HIDE_ALL_INDEX].widget, 
-				  TRUE); 
-	
-	gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_FILTER_INDEX].widget, 
-				  FALSE); 
-	
-	gtk_widget_set_sensitive (priv->popup_menu_uiinfo[POPUP_MENU_PLUGINS_INDEX].widget, 
-				  FALSE); 
-	
+	gpdf_annots_view_emit_ready (annots_view);
 
         return FALSE; 
 }
@@ -973,16 +1005,14 @@ gpdf_annots_view_popup_menu_item_filter_cb (GtkMenuItem *item,
 					    GPdfAnnotsView *annots_view)
 {
 	GPdfAnnotsViewPrivate *priv;
-	GladeXML *xml;
-	GtkWidget *glade_widget;
 	
 	g_return_if_fail (GPDF_IS_NON_NULL_ANNOTS_VIEW (annots_view));
 	
 	priv = annots_view->priv;
 	
 	gpdf_control_private_warn_dialog (priv->parent, 
-					  _("Not yet implemented !"),
-					  _("Annotations Filter feature not yet implemented ... Sorry."),
+					  _("Not yet implemented!"),
+					  _("Annotations Filter feature not yet implemented... Sorry."),
 					  TRUE);					  
 }
 
@@ -997,8 +1027,8 @@ gpdf_annots_view_popup_menu_item_plugins_cb (GtkMenuItem *item,
 	priv = annots_view->priv;
 	
 	gpdf_control_private_warn_dialog (priv->parent, 
-					  _("Not yet implemented !"),
-					  _("Annotations Plug-ins management feature not yet implemented ... Sorry."),
+					  _("Not yet implemented!"),
+					  _("Annotations Plug-ins management feature not yet implemented... Sorry."),
 					  TRUE);					  
 }
 
@@ -1011,6 +1041,9 @@ gpdf_annots_view_get_tools_menu (GPdfAnnotsView *annots_view)
 	g_return_val_if_fail (GPDF_IS_NON_NULL_ANNOTS_VIEW (annots_view), NULL);
 	
 	priv = annots_view->priv;
+
+	if (!gpdf_annots_view_have_annotations (annots_view))
+	  return NULL;
 	
 	if (!priv->popup_menu) {
 		priv->popup_menu = gtk_menu_new ();
@@ -1020,9 +1053,9 @@ gpdf_annots_view_get_tools_menu (GPdfAnnotsView *annots_view)
 					       (gpointer)annots_view);
 
 		item = priv->popup_menu_uiinfo[POPUP_MENU_SHOW_ALL_INDEX].widget;
-		gtk_widget_set_sensitive (item, FALSE); 
+		gtk_widget_set_sensitive (item, TRUE); 
 		item = priv->popup_menu_uiinfo[POPUP_MENU_HIDE_ALL_INDEX].widget;
-		gtk_widget_set_sensitive (item, FALSE); 
+		gtk_widget_set_sensitive (item, TRUE); 
 		item = priv->popup_menu_uiinfo[POPUP_MENU_FILTER_INDEX].widget;
 		gtk_widget_set_sensitive (item, FALSE); 
 		item = priv->popup_menu_uiinfo[POPUP_MENU_PLUGINS_INDEX].widget;
