@@ -21,9 +21,7 @@
 #include "gpdf-view.h"
 #include "gpdf-bookmarks-view.h"
 #include "gpdf-thumbnails-view.h"
-#ifdef USE_ANNOTS_VIEW
 #include "gpdf-annots-view.h"
-#endif
 #include "gpdf-hig-dialog.h"
 #include "gpdf-util.h"
 #include "pdf-info-dict-util.h"
@@ -95,7 +93,7 @@ struct _GPdfControlPrivate {
 
 /* Components paths */
 #define TOOLBAR_FIT_WIDTH_PATH		"/Toolbar/ZoomFitWidth"
-#define MENU_FIT_WIDTH_PATH		"/menu/View/View Items Placeholder/ZoomFitWidth"
+#define MENU_FIT_WIDTH_PATH		"/menu/View/Zoom Items Placeholder/ZoomFitWidth"
 #define TOOLBAR_TOOL_CONTROL_PATH	"/Toolbar/Tool Control Placeholder/ToolControl"
 #define TOOLBAR_PAGE_CONTROL_PATH	"/Toolbar/Page Control Placeholder/PageControl"
 
@@ -119,11 +117,6 @@ struct _GPdfControlPrivate {
 /* Components IDs */
 #define VIEW_SIDEBAR_COMP_ID		"ViewSidebar"
 
-/* Side page IDs */
-#define BOOKMARKS_PAGE_ID		"bookmarks"
-#define THUMBNAILS_PAGE_ID		"thumbnails"
-#define ANNOTS_PAGE_ID			"annots"
-
 #define PARENT_TYPE BONOBO_TYPE_CONTROL
 BONOBO_CLASS_BOILERPLATE (GPdfControl, gpdf_control,
 			  BonoboControl, PARENT_TYPE);
@@ -168,7 +161,6 @@ static void gpdf_control_annotation_toggled_cb	 (GPdfAnnotsView *gpdf_annots_vie
 static void gpdf_control_sidebar_page_changed_cb (GPdfSidebar *sidebar,
 						  const gchar *page_id,
 						  GPdfControl *control); 
-static const char *gpdf_control_get_title        (GPdfControl *gpdf_control);
 
 
 /*
@@ -334,7 +326,8 @@ gpdf_control_private_set_cursor	(GPdfControl * control,
 	priv = control->priv;
 	
 	parent_window = gtk_widget_get_parent_window (priv->vbox);
-	gdk_window_set_cursor (parent_window, cursor); 
+	if (GDK_IS_WINDOW (parent_window))
+	  gdk_window_set_cursor (parent_window, cursor); 
 	gdk_cursor_unref (cursor);
 	gdk_flush();	
 }
@@ -354,7 +347,8 @@ gpdf_control_private_set_wait_cursor (GPdfControl * control)
 	display = gtk_widget_get_display (priv->vbox);
 	cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
 	parent_window = gtk_widget_get_parent_window (priv->vbox);
-	gdk_window_set_cursor (parent_window, cursor); 
+	if (GDK_IS_WINDOW (parent_window))
+	  gdk_window_set_cursor (parent_window, cursor); 
 	gdk_cursor_unref (cursor);
 	gdk_flush();		
 }
@@ -370,7 +364,8 @@ gpdf_control_private_reset_cursor (GPdfControl * control)
 	priv = control->priv;
 
 	parent_window = gtk_widget_get_parent_window (priv->vbox);
-	gdk_window_set_cursor (parent_window, NULL); 
+	if (GDK_IS_WINDOW (parent_window))
+	  gdk_window_set_cursor (parent_window, NULL); 
 	gdk_flush();		
 }
 
@@ -449,7 +444,7 @@ gpdf_control_private_error_dialog (GPdfControl * control,
 				   body_text,
 				   modal);
 	but = gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     _("Ok"),
+				     GTK_STOCK_OK,
 				     GTK_RESPONSE_OK);
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dlg),
@@ -480,7 +475,7 @@ gpdf_control_private_warn_dialog (GPdfControl * control,
 				   body_text,
 				   modal);
 	but = gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     _("Ok"),
+				     GTK_STOCK_OK,
 				     GTK_RESPONSE_OK);
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dlg),
@@ -511,7 +506,7 @@ gpdf_control_private_info_dialog (GPdfControl * control,
 				   body_text,
 				   modal);
 	but = gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     _("Ok"),
+				     GTK_STOCK_OK,
 				     GTK_RESPONSE_OK);
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dlg),
@@ -528,35 +523,6 @@ gpdf_control_private_info_dialog (GPdfControl * control,
 	}
 }
 
-gint
-gpdf_control_private_question_dialog (GPdfControl * control,
-				      const gchar *header_text,
-				      const gchar *body_text)
-{
-	GtkWidget *dlg;
-	gint resp = GTK_RESPONSE_NONE;
-
-	g_return_val_if_fail (GPDF_IS_NON_NULL_CONTROL (control),
-			      resp);
-	dlg = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_QUESTION,
-				   header_text,
-				   body_text,
-				   TRUE);
-	(void)gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     _("No"),
-				     GTK_RESPONSE_YES);
-	(void)gtk_dialog_add_button (GTK_DIALOG (dlg),
-				     _("Yes"),
-				     GTK_RESPONSE_YES);
-	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
-					  GTK_WINDOW (dlg),
-					  NULL);
-	resp = gtk_dialog_run (GTK_DIALOG (dlg));
-	gtk_widget_destroy (dlg);
-
-	return resp;
-}
-
 void
 gpdf_control_private_display_help (BonoboControl *control,
 				   const gchar *section_id)
@@ -574,7 +540,7 @@ gpdf_control_private_display_help (BonoboControl *control,
 					section_id,
 					NULL) == FALSE)
 	{
-		const gchar *msg = g_strdup_printf ("Cannot access section <%s>",
+		const gchar *msg = g_strdup_printf ("Cannot access section \"%s\"",
 						    section_id);
 		gpdf_control_private_error_dialog (gpdf_control,
 						   _("Documentation Error"),
@@ -603,6 +569,84 @@ struct _GPdfPrintJob {
 	GtkWidget *progress_button;
 };
 
+/* FIXME: Does these 6 following funcs could be grouped in only 2? */
+static void
+gpdf_control_update_bookmarks_view_tools_menu (GPdfControl *gpdf_control)
+{
+	GPdfControlPrivate *priv;
+	GtkWidget *toolsmenu, *old; 
+
+	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (gpdf_control));
+	priv = gpdf_control->priv;
+
+	toolsmenu =
+		gpdf_bookmarks_view_get_tools_menu (
+			GPDF_BOOKMARKS_VIEW (priv->gpdf_bookmarks_view));
+	old = gpdf_sidebar_set_page_tools_menu (GPDF_SIDEBAR (priv->gpdf_sidebar),
+						GPDF_BOOKMARKS_VIEW_PAGE_ID, 
+						toolsmenu);
+	if (GTK_IS_MENU (old) && old != toolsmenu) gtk_widget_destroy (old); 
+}
+
+static void
+gpdf_control_bookmarks_view_ready (GtkWidget *w, GPdfControl *gpdf_control)
+{
+	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (gpdf_control));
+	gpdf_control_update_bookmarks_view_tools_menu (gpdf_control);
+}
+
+static void
+gpdf_control_update_thumbnails_view_tools_menu (GPdfControl *gpdf_control)
+{
+	GPdfControlPrivate *priv;
+	GtkWidget *toolsmenu, *old; 
+
+	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (gpdf_control));
+	priv = gpdf_control->priv;
+
+	toolsmenu =
+		gpdf_thumbnails_view_get_tools_menu (
+			GPDF_THUMBNAILS_VIEW (priv->gpdf_thumbnails_view));
+	old = gpdf_sidebar_set_page_tools_menu (GPDF_SIDEBAR (priv->gpdf_sidebar),
+						GPDF_THUMBNAILS_VIEW_PAGE_ID, 
+						toolsmenu); 
+	if (GTK_IS_MENU (old) && old != toolsmenu) gtk_widget_destroy (old); 
+}
+
+static void
+gpdf_control_thumbnails_view_ready (GtkWidget *w, GPdfControl *gpdf_control)
+{
+	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (gpdf_control));
+	gpdf_control_update_thumbnails_view_tools_menu (gpdf_control);
+}
+
+#ifdef USE_ANNOTS_VIEW
+static void
+gpdf_control_update_annots_view_tools_menu (GPdfControl *gpdf_control)
+{
+	GPdfControlPrivate *priv;
+	GtkWidget *toolsmenu, *old; 
+
+	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (gpdf_control));
+	priv = gpdf_control->priv;
+
+	toolsmenu =
+		gpdf_annots_view_get_tools_menu (
+			GPDF_ANNOTS_VIEW (priv->gpdf_annots_view));
+	old = gpdf_sidebar_set_page_tools_menu (GPDF_SIDEBAR (priv->gpdf_sidebar),
+						GPDF_ANNOTS_VIEW_PAGE_ID, 
+						toolsmenu); 
+	if (GTK_IS_MENU (old) && old != toolsmenu) gtk_widget_destroy (old); 	
+}
+
+static void
+gpdf_control_annots_view_ready (GtkWidget *w, GPdfControl *gpdf_control)
+{
+	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (gpdf_control));
+	gpdf_control_update_annots_view_tools_menu (gpdf_control);
+}
+#endif
+
 static void
 ui_component_set_sensitive (BonoboUIComponent *ui,
 			    const char *path,
@@ -654,6 +698,12 @@ gpdf_control_enable_ui (GPdfControl *control, gboolean sensitive)
 	ui_component_set_sensitive (uic, ZOOM_FIT_CMDPATH, sens_zoom);
 	ui_component_set_sensitive (uic, ZOOM_FIT_WIDTH_CMDPATH, sensitive);
 
+	gpdf_control_update_bookmarks_view_tools_menu (control);
+	gpdf_control_update_thumbnails_view_tools_menu (control);
+#ifdef USE_ANNOTS_VIEW
+	gpdf_control_update_annots_view_tools_menu (control);
+#endif
+
 	bonobo_ui_component_thaw (uic, NULL);	
 }
 
@@ -662,15 +712,19 @@ gpdf_print_job_prepare (GPdfPrintJob *pj)
 {
 	GnomePrintConfig *config;
 	gdouble width, height;
+	gboolean duplex;
 
 	config = gnome_print_job_get_config (pj->gnome_print_job);
 
 	/* width and height are returned in PS points :-) */
 	gnome_print_config_get_page_size (config, &width, &height);
+	gnome_print_config_get_boolean (config, 
+					(const guchar *)GNOME_PRINT_KEY_DUPLEX,
+					&duplex);
 
 	globalParams->setPSPaperWidth ((int)width);
 	globalParams->setPSPaperHeight ((int)height);
-	globalParams->setPSDuplex (gTrue);
+	globalParams->setPSDuplex (duplex);
 }
 
 static gboolean
@@ -807,23 +861,6 @@ using_postscript_printer (GnomePrintConfig *config)
 	return FALSE;
 }
 
-static void
-gpdf_control_no_preview_alert (GPdfControl *control)
-{
-	GtkWidget *dlg;
-
-	dlg = gpdf_hig_dialog_new (
-		GTK_STOCK_DIALOG_ERROR,
-		_("Print preview is not available in this program."),
-		NULL, FALSE);
-	gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK, GTK_RESPONSE_OK);
-	g_signal_connect_swapped (G_OBJECT (dlg), "response",
-				  G_CALLBACK (gtk_widget_destroy), dlg);
-	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
-					  GTK_WINDOW (dlg), NULL);
-	gtk_widget_show (dlg);
-}
-
 static void
 gpdf_control_no_postscript_printer_alert (GPdfControl *control,
 					  GnomePrintConfig *config)
@@ -895,6 +932,10 @@ gpdf_control_print_dialog_new (GPdfControl *control, GnomePrintJob *job)
 		NULL, (const guchar *)pages_label);
 	g_free (pages_label);
 
+	gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog),
+					   GNOME_PRINT_DIALOG_RESPONSE_PREVIEW,
+					   FALSE);
+
 	bonobo_control_set_transient_for (BONOBO_CONTROL (control),
 					  GTK_WINDOW (dialog),
 					  NULL);
@@ -940,11 +981,6 @@ gpdf_control_print (GPdfControl *control)
 	response = gtk_dialog_run (GTK_DIALOG (print_dialog));
 	gtk_widget_hide (print_dialog);
 
-	if (response == GNOME_PRINT_DIALOG_RESPONSE_PREVIEW) {
-		gpdf_control_no_preview_alert (control);
-		goto exit;
-	}
-
 	if (response != GNOME_PRINT_DIALOG_RESPONSE_PRINT)
 		goto exit;
 
@@ -1483,9 +1519,6 @@ gc_ui_set_pixbufs (GPdfControl *control)
 {
 	GtkWidget *gpdf_view;
 	BonoboUIComponent *ui_component;
-	GtkIconSet *icon_set;
-	GdkPixbuf *pixbuf, *menu_pixbuf;
-	gchar *pixbuf_xml, *menu_pixbuf_xml;
 
 	gpdf_view = control->priv->gpdf_view;
 
@@ -1581,16 +1614,16 @@ gpdf_control_read_sidebar_state (GPdfControl *gpdf_control)
 #ifndef USE_ANNOTS_VIEW
 	/*
 	 * If annots view is disabled and saved page id
-	 * is ANNOTS_PAGE_ID,  change it to Bookmarks page.
+	 * is GPDF_ANNOTS_VIEW_PAGE_ID,  change it to Bookmarks page.
 	 */
-	if (!strncmp(page_id, ANNOTS_PAGE_ID, strlen(ANNOTS_PAGE_ID)))
-		page_id = BOOKMARKS_PAGE_ID;
+	if (!strncmp(page_id, GPDF_ANNOTS_VIEW_PAGE_ID, strlen(GPDF_ANNOTS_VIEW_PAGE_ID)))
+		page_id = GPDF_BOOKMARKS_VIEW_PAGE_ID;
 #endif
 	
 	/* Select sidebar page saved in gconf value sidebar_page */
 	gpdf_control_sidebar_page_changed_cb
 		(GPDF_SIDEBAR (gpdf_control->priv->gpdf_sidebar),
-		 (page_id && *page_id ? page_id : BOOKMARKS_PAGE_ID),
+		 (page_id && *page_id ? page_id : GPDF_BOOKMARKS_VIEW_PAGE_ID),
 		 gpdf_control); 
 }
 
@@ -1599,16 +1632,22 @@ gpdf_control_save_sidebar_state (GPdfControl *gpdf_control)
 {
 	const gchar *cur_page_id = gpdf_sidebar_get_current_page_id
 	      (GPDF_SIDEBAR (gpdf_control->priv->gpdf_sidebar));
-	
+
+	DBG (g_message ("gpdf_control_save_sidebar_state: opened = %s",
+			GTK_WIDGET_VISIBLE (gpdf_control->priv->gpdf_sidebar) ?
+			"TRUE" : "FALSE")); 
+	DBG (g_message ("gpdf_control_save_sidebar_state: cur_view = '%s'",
+			cur_page_id ? cur_page_id : GPDF_BOOKMARKS_VIEW_PAGE_ID)); 
+
 	/* Save sidebar state */
 	eel_gconf_set_boolean
-	  (CONF_WINDOWS_SHOW_SIDEBAR,
-	   GTK_WIDGET_MAPPED (gpdf_control->priv->gpdf_sidebar));
+		(CONF_WINDOWS_SHOW_SIDEBAR,
+		 GTK_WIDGET_VISIBLE (gpdf_control->priv->gpdf_sidebar));
 	
 	/* And side bar current page id */
 	eel_gconf_set_string
-	  (CONF_WINDOWS_SIDEBAR_PAGE,
-	   cur_page_id ? cur_page_id : BOOKMARKS_PAGE_ID); 
+		(CONF_WINDOWS_SIDEBAR_PAGE,
+		 cur_page_id ? cur_page_id : GPDF_BOOKMARKS_VIEW_PAGE_ID); 
 }
 
 static void
@@ -1658,36 +1697,11 @@ gpdf_control_activate (BonoboControl *control, gboolean activate)
 		BONOBO_CONTROL_CLASS, activate, (control, activate));
 }
 
-static const char *
-gpdf_control_get_title (GPdfControl *gpdf_control)
-{
-	gchar *title;
-	GnomeVFSURI *vfs_uri;
-
-	g_return_val_if_fail (gpdf_control->priv->title, _("PDF Document"));
-	
-	vfs_uri = gnome_vfs_uri_new ((const gchar *)gpdf_control->priv->title);
-	if (vfs_uri) {
-		const char *esctlt =
-			gnome_vfs_uri_is_local (vfs_uri) ?
-			g_strdup (gnome_vfs_uri_get_path (vfs_uri)) :
-			gnome_vfs_uri_to_string (vfs_uri,
-						 GNOME_VFS_URI_HIDE_NONE);
-		title = gnome_vfs_unescape_string_for_display (esctlt);
-		g_free ((gpointer)esctlt); 
-                gnome_vfs_uri_unref (vfs_uri);
-	} else
-		title = g_strdup (_("PDF Document"));
-
-	return title;
-}
-
 static GPdfBookmarksView *
 gpdf_control_get_bookmarks_view (GPdfControl *gpdf_control)
 {
 	GPdfControlPrivate *priv;
 	GPdfView *gpdf_view;
-	GtkWidget *toolsmenu, *old; 
 
 	priv = gpdf_control->priv;
 	gpdf_view = GPDF_VIEW (priv->gpdf_view);
@@ -1705,15 +1719,12 @@ gpdf_control_get_bookmarks_view (GPdfControl *gpdf_control)
 			      "bookmark_selected",
 			      G_CALLBACK (gpdf_control_bookmark_selected_cb),
 			      gpdf_control);
-	}
 
-	toolsmenu =
-		gpdf_bookmarks_view_get_tools_menu (
-			GPDF_BOOKMARKS_VIEW (priv->gpdf_bookmarks_view));
-	old = gpdf_sidebar_set_page_tools_menu (GPDF_SIDEBAR (priv->gpdf_sidebar),
-						BOOKMARKS_PAGE_ID, 
-						toolsmenu);
-	if (GTK_IS_MENU (old)) gtk_widget_destroy (old); 
+	    g_signal_connect (G_OBJECT (priv->gpdf_bookmarks_view),
+			      "ready",
+			      G_CALLBACK (gpdf_control_bookmarks_view_ready),
+			      gpdf_control);
+	}
 
 	return (GPDF_BOOKMARKS_VIEW (priv->gpdf_bookmarks_view));
 }
@@ -1723,7 +1734,6 @@ gpdf_control_get_thumbnails_view (GPdfControl *gpdf_control)
 {
 	GPdfControlPrivate *priv;
 	GPdfView *gpdf_view;
-	GtkWidget *toolsmenu, *old; 
 
 	priv = gpdf_control->priv;
 	gpdf_view = GPDF_VIEW (priv->gpdf_view);
@@ -1741,15 +1751,12 @@ gpdf_control_get_thumbnails_view (GPdfControl *gpdf_control)
 			      "thumbnail_selected",
 			      G_CALLBACK (gpdf_control_thumbnail_selected_cb),
 			      gpdf_control);	    
+
+	    g_signal_connect (G_OBJECT (priv->gpdf_thumbnails_view),
+			      "ready",
+			      G_CALLBACK (gpdf_control_thumbnails_view_ready),
+			      gpdf_control);
 	}
-	
-	toolsmenu =
-		gpdf_thumbnails_view_get_tools_menu (
-			GPDF_THUMBNAILS_VIEW (priv->gpdf_thumbnails_view));
-	old = gpdf_sidebar_set_page_tools_menu (GPDF_SIDEBAR (priv->gpdf_sidebar),
-						THUMBNAILS_PAGE_ID, 
-						toolsmenu); 
-	if (GTK_IS_MENU (old)) gtk_widget_destroy (old); 
 
 	return (GPDF_THUMBNAILS_VIEW (priv->gpdf_thumbnails_view));
 }
@@ -1760,7 +1767,6 @@ gpdf_control_get_annots_view (GPdfControl *gpdf_control)
 {
 	GPdfControlPrivate *priv;
 	GPdfView *gpdf_view;
-	GtkWidget *toolsmenu, *old; 
 
 	priv = gpdf_control->priv;
 	gpdf_view = GPDF_VIEW (priv->gpdf_view);
@@ -1784,16 +1790,13 @@ gpdf_control_get_annots_view (GPdfControl *gpdf_control)
 			      "annotation_toggled",
 			      G_CALLBACK (gpdf_control_annotation_toggled_cb),
 			      gpdf_control);
+
+	    g_signal_connect (G_OBJECT (priv->gpdf_annots_view),
+			      "ready",
+			      G_CALLBACK (gpdf_control_annots_view_ready),
+			      gpdf_control);
 	}
 
-	toolsmenu =
-		gpdf_annots_view_get_tools_menu (
-			GPDF_ANNOTS_VIEW (priv->gpdf_annots_view));
-	old = gpdf_sidebar_set_page_tools_menu (GPDF_SIDEBAR (priv->gpdf_sidebar),
-						ANNOTS_PAGE_ID, 
-						toolsmenu); 
-	if (GTK_IS_MENU (old)) gtk_widget_destroy (old); 
-	
 	return (GPDF_ANNOTS_VIEW (priv->gpdf_annots_view));
 }
 #endif
@@ -1823,7 +1826,6 @@ gpdf_control_pdf_doc_changed (GPdfControl *gpdf_control)
 	
 	if (priv->pdf_doc) {
 		gpdf_view_set_pdf_doc (gpdf_view, priv->pdf_doc);
-		gpdf_control_enable_ui (gpdf_control, TRUE);
 		gpdf_page_control_set_total_pages (
 			page_control,
 			priv->pdf_doc->getNumPages ());
@@ -1836,10 +1838,11 @@ gpdf_control_pdf_doc_changed (GPdfControl *gpdf_control)
 		gpdf_annots_view_set_pdf_doc (gpdf_annots_view,
 					      priv->pdf_doc);
 #endif
-	} else {
-		gpdf_control_enable_ui (gpdf_control, FALSE);
-		gpdf_page_control_set_total_pages (page_control, -1);
-	}
+	} else
+	  gpdf_page_control_set_total_pages (page_control, -1);
+
+	gpdf_control_enable_ui (gpdf_control,
+				priv->pdf_doc != NULL ? TRUE : FALSE);
 }
 
 static void
@@ -2226,12 +2229,12 @@ gpdf_control_sidebar_page_changed_cb (GPdfSidebar *sidebar,
 	
 	g_return_if_fail (GPDF_IS_CONTROL (control));
 
-	if (!strncmp (page_id, BOOKMARKS_PAGE_ID, strlen(BOOKMARKS_PAGE_ID)))
+	if (!strncmp (page_id, GPDF_BOOKMARKS_VIEW_PAGE_ID, strlen(GPDF_BOOKMARKS_VIEW_PAGE_ID)))
 		page = control->priv->gpdf_bookmarks_view;
-	else if (!strncmp (page_id, THUMBNAILS_PAGE_ID, strlen(THUMBNAILS_PAGE_ID)))
+	else if (!strncmp (page_id, GPDF_THUMBNAILS_VIEW_PAGE_ID, strlen(GPDF_THUMBNAILS_VIEW_PAGE_ID)))
 		page = control->priv->gpdf_thumbnails_view;
 #ifdef USE_ANNOTS_VIEW
-	else if (!strncmp (page_id, ANNOTS_PAGE_ID, strlen(ANNOTS_PAGE_ID)))
+	else if (!strncmp (page_id, GPDF_ANNOTS_VIEW_PAGE_ID, strlen(GPDF_ANNOTS_VIEW_PAGE_ID)))
 		page = control->priv->gpdf_annots_view;
 #endif
 	
@@ -2270,16 +2273,16 @@ gpdf_control_setup_view_widgets (GPdfControl *control)
 			  G_CALLBACK (gpdf_control_sidebar_close_requested_cb),
 			  control);
 	gpdf_sidebar_add_page (GPDF_SIDEBAR (sidebar),
-			       _("Bookmarks"), BOOKMARKS_PAGE_ID,
+			       _("Bookmarks"), GPDF_BOOKMARKS_VIEW_PAGE_ID,
 			       NULL, 
 			       FALSE);
 	gpdf_sidebar_add_page (GPDF_SIDEBAR (sidebar),
-			       _("Thumbnails"), THUMBNAILS_PAGE_ID,
+			       _("Pages"), GPDF_THUMBNAILS_VIEW_PAGE_ID,
 			       NULL, 
 			       FALSE);
 #ifdef USE_ANNOTS_VIEW
 	gpdf_sidebar_add_page (GPDF_SIDEBAR (sidebar),
-			       _("Annotations"), ANNOTS_PAGE_ID,
+			       _("Annotations"), GPDF_ANNOTS_VIEW_PAGE_ID,
 			       NULL, 
 			       FALSE);
 #endif
